import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear, scaleTime, timeFormat, extent } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

// Defining attributes for the line chart
const width = 960;
const height = 500;
const margin = {
  top: 30,
  right: 20,
  bottom: 60,
  left: 150,
};
const xAxisLabelOffset = 45;
const yAxisLabelOffset = 85;
const xValue = (d) => d.year;
const xAxisLabel = 'Date';
const yValue = (d) => d.population;
const yAxisLabel = 'Population Growth Rate';

// Defining format for the x axis
const xAxisTickFormat = timeFormat("%Y");

const App = () => {
  // Loading data from CSV
  const data = useData();

  if (!data) {
    return <pre>Loading data...</pre>;
  }
	
  console.log(data[0]);
  
  // Calculating height and width
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  // Declaring xScale and yScale for plotting
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  	.nice();
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
  	.nice();

  // Returning svg for displaying
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={7}
        />
        <AxisLeft
          yScale={yScale}
          innerWidth={innerWidth}
        />
				<Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
          circleRadius={3}
        />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
          tickOffset={7}
        >
          {xAxisLabel}
        </text>
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset},${innerHeight / 2}) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
